@@ -34,6 +34,16 @@ def do_exit_error(msg, trace_back=True, exit_code=EXIT_ERROR):
     sys.exit(exit_code)
 
 
+def create_nef_app():
+    import typer
+
+    from nef_pipelines import nef_app
+
+    nef_app.app = typer.Typer(no_args_is_help=True)
+    app = nef_app.app  # noqa: F841
+    return nef_app
+
+
 def main():
     try:
         import typer
@@ -49,10 +59,7 @@ def main():
         do_exit_error(msg, e)
 
     try:
-        from nef_pipelines import nef_app
-
-        nef_app.app = typer.Typer(no_args_is_help=True)
-        app = nef_app.app  # noqa: F841
+        nef_app = create_nef_app()
 
     except Exception as e:
         msg = """\
@@ -68,14 +75,13 @@ def main():
         import nef_pipelines.tools.frames  # noqa: F401
         import nef_pipelines.tools.header  # noqa: F401
         import nef_pipelines.tools.stream  # noqa: F401
-
-        # import nef_pipelines.tools.test  # noqa: F401
+        import nef_pipelines.tools.test  # noqa: F401
         import nef_pipelines.transcoders.fasta  # noqa: F401
         import nef_pipelines.transcoders.mars  # noqa: F401
         import nef_pipelines.transcoders.nmrpipe  # noqa: F401
         import nef_pipelines.transcoders.nmrview  # noqa: F401
         import nef_pipelines.transcoders.pales  # noqa: F401
-        import nef_pipelines.transcoders.pdb  # noqa: F401
+        import nef_pipelines.transcoders.pdbx  # noqa: F401
 
     except Exception as e:
         msg = """\
